import { compile as platformCompile } from '@lwc/sfdc-lwc-compiler';
import { LogLevel, Workspace } from '../../types/index.js';
import { measureOperationTime } from '../util/telemetry.js';
function transformOptionsToPlatformCompileConfig(ctx, transformOptions, modulePath) {
    const { enableDynamicComponents, enableLightningWebSecurityTransforms, experimentalComplexExpressions, apiVersion, name, namespace, experimentalDynamicComponent, outputConfig, } = transformOptions;
    const options = {
        // variable options
        allowDynamicComponents: enableDynamicComponents,
        enableLightningWebSecurityTransforms: enableLightningWebSecurityTransforms,
        enableTemplateExpressions: experimentalComplexExpressions,
        apiVersion: apiVersion,
        // Standard options
        disableProcessNodeEnv: true,
        dynamicImport: 'allowed',
        forceNamedExports: true,
        strictCSSTokenCollection: true,
        // Enable HMR always in dev server
        enableHmr: true,
    };
    const getBundleType = () => {
        if (ctx.config.workspace === Workspace.Internal || ctx.config.workspace === Workspace.Mrt) {
            return 'internal';
        }
        return 'platform';
    };
    const bundle = {
        type: getBundleType(),
        name: name,
        namespace: namespace ?? 'c',
        files: ctx.moduleGraph.getModuleFiles(name, namespace ?? '', modulePath),
        options,
    };
    const compilerConfigs = [
        {
            outputConfig: { minify: false, sourcemap: !!outputConfig?.sourcemap },
            experimentalDynamicComponent: experimentalDynamicComponent,
        },
    ];
    return {
        bundle,
        compilerConfigs,
    };
}
export async function compile(ctx, modulePath, options, logger, lifecycle) {
    const compileConfig = transformOptionsToPlatformCompileConfig(ctx, options, modulePath);
    const result = await measureOperationTime('compile-time', () => platformCompile(compileConfig), lifecycle);
    if (!result.success) {
        logger.log(LogLevel.error, `Failed to compile ${modulePath}. \n\tDiagnostics: ${JSON.stringify(result.diagnostics)}`);
        return { code: undefined, warnings: [result.diagnostics.toString()] };
    }
    return {
        code: result.results?.[0].code,
        warnings: result.diagnostics.length ? [result.diagnostics.toString()] : [],
    };
}
//# sourceMappingURL=lexBundler.js.map